@@ -20,7 +20,7 @@ class LayoutSettings:
         self.font_scale = 1
         self._font_family = {'code':'var(--jp-code-font-family)','text':'sans-serif'}
         self._footer_text = 'IPySlides | <a style="color:skyblue;" href="https://github.com/massgh/ipyslides">github-link</a>'
-        self._content_width = '100%'
+        self._content_width = '90%' #Better
         self._breakpoint_width = '650px'
         
         self.height_slider = self.widgets.sliders.height
@@ -36,10 +36,7 @@ class LayoutSettings:
         self.btn_zoom  = self.widgets.toggles.zoom
         self.btn_timer = self.widgets.toggles.timer
         self.box = self.widgets.panelbox
-        self.box.on_displayed(lambda change: self.__add_js()) # First attempt of Javascript to work
-        
-        with self._instructions:
-            write(intro.instructions) 
+        self.box.on_displayed(self._on_displayed) # First attempt of Javascript to work
         
         self.theme_dd.observe(self._update_theme,names=['value'])
         self.scale_slider.observe(self.__set_font_scale,names=['value'])
@@ -52,11 +49,16 @@ class LayoutSettings:
         self.sidebar_switch.observe(self._toggle_sidebar,names=['value'])        
         self.sidebar_switch.value = 0 # Initial Call must be inline, so that things should be shown outside Jupyterlab always
         
-    
         self._update_theme() #Trigger Theme and Javascript in it
         self.set_code_style() #Trigger CSS in it, must
-        self.set_layout(center = True, content_width = '90%') # Trigger this as well
+        self.set_layout(center = True) # Trigger this as well
         
+    def _on_displayed(self,change):
+        self.__add_js()
+        self._instructions.clear_output(wait=True) # This make sure that instructions are not duplicated
+        with self._instructions:
+            write(intro.instructions)
+            
     def set_animation(self,name):
         "Set animation style or pass None to disable animation."
         if name is None:
@@ -116,14 +118,14 @@ class LayoutSettings:
             return display(html('style', 'code:before{ display:inline-block !important; }'))
         return display(html('style', 'code:before{ display:none !important; }'))
     
-    def set_layout(self,center = True, content_width='100%'):
+    def set_layout(self,center = True, content_width = None):
         "Central aligment of slide by default. If False, left-top aligned."
-        self._content_width = content_width
+        self._content_width = content_width if content_width else self._content_width # user selected
         style_dict = {'display':'block','width':content_width} #block is must
         if center:
             style_dict.update(dict(margin = 'auto',align_items = 'center',justify_content = 'center'))
-        else:
-            style_dict.update(dict(margin = '2px 8px 2px 8px',align_items = 'baseline',justify_content = 'flex-start'))
+        else: #container still should be in the center horizontally with auto margin
+            style_dict.update(dict(margin = '8px auto',align_items = 'baseline',justify_content = 'flex-start'))
         
         for k,v in style_dict.items():
             setattr(self.widgets.outputs.slide.layout, k, v)
@@ -144,6 +146,10 @@ class LayoutSettings:
         self.widgets.mainbox.layout.width = '{}vw'.format(self.width_slider.value)  
         self._toggle_sidebar(change=None) #modify width of sidebar or display it inline
         self._emit_resize_event() # Although its in _toggle_sidebar, but for being safe, do this
+        
+        if not self.btn_fs.value: #If not fullscreen, then update breakpoint, so that it can be used in CSS
+            self._breakpoint_width = f'{int(100*650/self.width_slider.value)}px'
+        
         self._update_theme(change=None) # For updating size and breakpoints
             
                      
@@ -176,7 +182,6 @@ class LayoutSettings:
                         )
         
         # Update CSS
-        self.widgets.htmls.theme.value = theme_css
         if self.reflow_check.value:
             theme_css = theme_css + f"\n.SlideArea * {{max-height:max-content !important;}}\n"
         
